@@ -2,29 +2,27 @@
 calphy: a Python library and command line interface for automated free
 energy calculations.
 
-Copyright 2021  (c) Sarath Menon^1, Yury Lysogorskiy^1, Ralf Drautz^1
-^1: Ruhr-University Bochum, Bochum, Germany
+calphy: a Python library and command line interface for automated free
+energy calculations.
+
+Copyright 2021  (c) Sarath Menon^1, Yury Lysogorskiy^2, Ralf Drautz^2
+^1: Max Planck Institut für Eisenforschung, Dusseldorf, Germany 
+^2: Ruhr-University Bochum, Bochum, Germany
+
+calphy is published and distributed under the Academic Software License v1.0 (ASL). 
+calphy is distributed in the hope that it will be useful for non-commercial academic research, 
+but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+calphy API is published and distributed under the BSD 3-Clause "New" or "Revised" License
+See the LICENSE FILE for more details. 
 
 More information about the program can be found in:
-Menon, Sarath, Yury Lysogorskiy, Jutta Rogal, and Ralf Drautz. 
-“Automated Free Energy Calculation from Atomistic Simulations.” 
-ArXiv:2107.08980 [Cond-Mat], July 19, 2021. 
-http://arxiv.org/abs/2107.08980.
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-See the LICENSE file.
+Menon, Sarath, Yury Lysogorskiy, Jutta Rogal, and Ralf Drautz.
+“Automated Free Energy Calculation from Atomistic Simulations.” Physical Review Materials 5(10), 2021
+DOI: 10.1103/PhysRevMaterials.5.103801
 
 For more information contact:
-sarath.menon@ruhr-uni-bochum.de
+sarath.menon@ruhr-uni-bochum.de/yury.lysogorskiy@icams.rub.de
+
 """
 
 import numpy as np
@@ -534,6 +532,8 @@ class Phase:
         lmp.command("echo              log")
         lmp.command("variable          li equal %f"%li)
         lmp.command("variable          lf equal %f"%lf)
+        lmp.command("variable          p0 equal %f"%p0)
+        lmp.command("variable          pf equal %f"%pf)
 
         #read in conf
         conf = os.path.join(self.simfolder, "conf.dump")
@@ -556,10 +556,11 @@ class Phase:
         lmp.command("variable          step    equal step")
         lmp.command("variable          dU      equal pe/atoms")
         lmp.command("variable          lambda equal ramp(${li},${lf})")
+        lmp.command("variable          pp equal ramp(${p0},${pf})")
 
         lmp.command("fix               f2 all npt temp %f %f %f %s %f %f %f"%(t0, t0, self.calc.md.thermostat_damping,
                                         self.iso, p0, pf, self.calc.md.barostat_damping))
-        lmp.command("fix               f3 all print 1 \"${dU} $(press) $(vol) ${lambda}\" screen no file forward_%d.dat"%iteration)
+        lmp.command("fix               f3 all print 1 \"${dU} ${pp} $(vol) ${lambda}\" screen no file forward_%d.dat"%iteration)
         lmp.command("run               %d"%self.calc._n_sweep_steps)
 
         lmp.command("unfix             f2")
@@ -573,10 +574,11 @@ class Phase:
 
         #start reverse loop
         lmp.command("variable          lambda equal ramp(${lf},${li})")
+        lmp.command("variable          pp equal ramp(${pf},${p0})")
 
         lmp.command("fix               f2 all npt temp %f %f %f %s %f %f %f"%(t0, t0, self.calc.md.thermostat_damping,
                                         self.iso, pf, p0, self.calc.md.barostat_damping))
-        lmp.command("fix               f3 all print 1 \"${dU} $(press) $(vol) ${lambda}\" screen no file backward_%d.dat"%iteration)
+        lmp.command("fix               f3 all print 1 \"${dU} ${pp} $(vol) ${lambda}\" screen no file backward_%d.dat"%iteration)
         lmp.command("run               %d"%self.calc._n_sweep_steps)
 
         lmp.close()
